;; Generated package description from polymode.el  -*- no-byte-compile: t -*-
(define-package "polymode" "0.2.2.0.20250531.193800" "Extensible framework for multiple major modes" '((emacs "25")) :commit "fabe53a5ab86eaaa39258acf35e1b25498cb7384" :maintainer '("Vitalie Spinu" . "spinuvit@gmail.com") :keywords '("languages" "multi-modes" "processes") :url "https://github.com/polymode/polymode")
